==> webkit2gtk_2.39.3.orig.tar.xz: webkitgtk-2.39.3/Source/WebKit/Platform/IPC/DaemonDecoder.cpp <==
/*
 * Copyright (C) 2021 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#include "config.h"
#include "DaemonDecoder.h"

namespace WebKit {

namespace Daemon {

Decoder::~Decoder()
{
    ASSERT(m_bufferPosition == m_buffer.size());
}

bool Decoder::bufferIsLargeEnoughToContainBytes(size_t bytes) const
{
    return bytes <= m_buffer.size() - m_bufferPosition;
}

bool Decoder::decodeFixedLengthData(uint8_t* data, size_t size)
{
    if (!bufferIsLargeEnoughToContainBytes(size))
        return false;
    memcpy(data, m_buffer.data() + m_bufferPosition, size);
    m_bufferPosition += size;
    return true;
}

const uint8_t* Decoder::decodeFixedLengthReference(size_t size)
{
    if (!bufferIsLargeEnoughToContainBytes(size))
        return nullptr;
    const uint8_t* data = m_buffer.data() + m_bufferPosition;
    m_bufferPosition += size;
    return data;
}

} // namespace Daemon

} // namespace WebKit

==> webkit2gtk_2.47.1.orig.tar.xz: webkitgtk-2.47.1/Source/WebKit/Platform/IPC/DaemonDecoder.cpp <==
/*
 * Copyright (C) 2021 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#include "config.h"
#include "DaemonDecoder.h"

#include <wtf/StdLibExtras.h>

WTF_ALLOW_UNSAFE_BUFFER_USAGE_BEGIN

namespace WebKit {

namespace Daemon {

Decoder::~Decoder()
{
    ASSERT(m_bufferPosition == m_buffer.size());
}

bool Decoder::bufferIsLargeEnoughToContainBytes(size_t bytes) const
{
    return bytes <= m_buffer.size() - m_bufferPosition;
}

bool Decoder::decodeFixedLengthData(std::span<uint8_t> data)
{
    if (!bufferIsLargeEnoughToContainBytes(data.size()))
        return false;
    memcpySpan(data, m_buffer.subspan(m_bufferPosition, data.size()));
    m_bufferPosition += data.size();
    return true;
}

std::span<const uint8_t> Decoder::decodeFixedLengthReference(size_t size)
{
    if (!bufferIsLargeEnoughToContainBytes(size))
        return { };
    auto data = m_buffer.subspan(m_bufferPosition, size);
    m_bufferPosition += size;
    return data;
}

} // namespace Daemon

} // namespace WebKit

WTF_ALLOW_UNSAFE_BUFFER_USAGE_END
